@@ -1651,5 +1651,1016 @@ class TestHelperMethods:
         assert query._operations_performed is True
 
 
+# ===== PHASE 1: TEXT SEARCH METHODS TESTS =====
+
+
+@pytest.fixture
+def text_search_store():
+    """Create a store with diverse data for text search testing."""
+    store = ElementStore()
+
+    elements_data = [
+        {
+            "id": "person-1",
+            "class_id": "Person",
+            "name": "John Doe",
+            "email": "john@example.com",
+            "bio": "Senior developer specializing in Python",
+            "age": 25,
+            "status": "active",
+            "skills": ["python", "javascript", "typescript"],
+        },
+        {
+            "id": "person-2",
+            "class_id": "Person",
+            "name": "Jane Smith",
+            "email": "jane@company.com",
+            "bio": "JavaScript developer and team lead",
+            "age": 30,
+            "status": "active",
+            "skills": ["javascript", "react", "nodejs"],
+        },
+        {
+            "id": "person-3",
+            "class_id": "Person",
+            "name": "Bob Johnson",
+            "email": "bob@gmail.com",
+            "bio": "Machine learning engineer",
+            "age": 35,
+            "status": "inactive",
+            "skills": ["python", "ml", "tensorflow"],
+        },
+        {
+            "id": "article-1",
+            "class_id": "Article",
+            "title": "Introduction to Python",
+            "content": "Python is a versatile programming language",
+            "author": "John Doe",
+            "tags": ["python", "programming", "tutorial"],
+            "published": True,
+        },
+        {
+            "id": "article-2",
+            "class_id": "Article",
+            "title": "JavaScript Best Practices",
+            "content": "Learn modern JavaScript development techniques",
+            "author": "Jane Smith",
+            "tags": ["javascript", "best-practices"],
+            "published": True,
+        },
+        {
+            "id": "file-1",
+            "class_id": "File",
+            "filename": "report_2024.pdf",
+            "path": "/documents/reports/",
+            "size": 1024,
+        },
+        {
+            "id": "file-2",
+            "class_id": "File",
+            "filename": "test_data.xlsx",
+            "path": "/documents/data/",
+            "size": 2048,
+        },
+    ]
+
+    for elem_data in elements_data:
+        element_id = elem_data.pop("id")
+        class_id = elem_data.pop("class_id")
+        properties = ElementProperties(**elem_data)
+        details = ElementDetails(
+            id=element_id, class_id=class_id, type=NodeTypes.NODE, properties=properties
+        )
+        element = BaseElement(details, store)
+        store.elements[element_id] = element
+
+    return store
+
+
+class TestFullTextSearch:
+    """Test fullTextSearch method."""
+
+    def test_search_across_all_text_properties(self, text_search_store):
+        """Should search across all text properties by default."""
+        results = (
+            GraphQuery(text_search_store).classId("Person").full_text_search("john").r()
+        )
+
+        assert len(results) > 0
+        # Should find 'john' in name or email
+        assert any("john" in r.properties.name.lower() for r in results)
+
+    def test_search_specific_properties(self, text_search_store):
+        """Should search only specified properties."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .full_text_search("example", {"properties": ["email"]})
+            .r()
+        )
+
+        assert len(results) > 0
+        for r in results:
+            assert "example" in r.properties.email.lower()
+
+    def test_and_operator_default(self, text_search_store):
+        """Should use AND operator by default."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .full_text_search("john developer")
+            .r()
+        )
+
+        # Should match elements with both 'john' AND 'developer'
+        assert (
+            len(results) == 1
+        )  # Should only find person-1 (John Doe with "developer" in bio)
+        for r in results:
+            # Use items() to get all properties including Pydantic extras
+            text_values = " ".join(
+                str(v) for k, v in r.properties.items() if isinstance(v, str)
+            ).lower()
+            assert "john" in text_values and "developer" in text_values
+
+    def test_or_operator(self, text_search_store):
+        """Should support OR operator."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .full_text_search("john jane", {"operator": "OR"})
+            .r()
+        )
+
+        assert len(results) >= 2  # Should find both John and Jane
+        names = [r.properties.name for r in results]
+        assert any("John" in name for name in names)
+        assert any("Jane" in name for name in names)
+
+    def test_case_sensitive_search(self, text_search_store):
+        """Should support case sensitive search."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .full_text_search("John", {"case_sensitive": True})
+            .r()
+        )
+
+        for r in results:
+            text_values = " ".join(
+                str(v) for v in r.properties.__dict__.values() if isinstance(v, str)
+            )
+            assert "John" in text_values  # Exact case
+
+    def test_exact_match(self, text_search_store):
+        """Should support exact matching."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .full_text_search("John Doe", {"exact": True})
+            .r()
+        )
+
+        # Exact match should be more restrictive
+        assert isinstance(results, list)
+
+    def test_empty_query_returns_all(self, text_search_store):
+        """Should return all elements when query is empty."""
+        all_persons = GraphQuery(text_search_store).classId("Person").r()
+        filtered = (
+            GraphQuery(text_search_store).classId("Person").full_text_search("").r()
+        )
+
+        assert len(filtered) == len(all_persons)
+
+    def test_no_matches(self, text_search_store):
+        """Should return empty list when no matches found."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .full_text_search("nonexistentterm12345")
+            .r()
+        )
+
+        assert results == []
+
+    def test_chaining_with_filters(self, text_search_store):
+        """Should chain with other query methods."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .full_text_search("john")
+            .where("age", FilterOperator.GT, 20)
+            .r()
+        )
+
+        assert isinstance(results, list)
+        for r in results:
+            assert r.properties.age > 20
+
+
+class TestWildcardSearch:
+    """Test wildcardSearch method."""
+
+    def test_asterisk_wildcard(self, text_search_store):
+        """Should match patterns with * wildcard."""
+        results = (
+            GraphQuery(text_search_store).classId("Person").wildcard_search("J*").r()
+        )
+
+        assert len(results) > 0
+        for r in results:
+            assert r.properties.name.startswith("J")
+
+    def test_question_mark_wildcard(self, text_search_store):
+        """Should match patterns with ? wildcard."""
+        results = (
+            GraphQuery(text_search_store).classId("Person").wildcard_search("J?hn*").r()
+        )
+
+        assert len(results) > 0
+        for r in results:
+            assert re.match(r"^J.hn", r.properties.name)
+
+    def test_specific_property(self, text_search_store):
+        """Should search specific property."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .wildcard_search("*@example.com", "email")
+            .r()
+        )
+
+        assert len(results) > 0
+        for r in results:
+            assert r.properties.email.endswith("@example.com")
+
+    def test_case_sensitive(self, text_search_store):
+        """Should support case sensitive matching."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .wildcard_search("John*", "name", {"case_sensitive": True})
+            .r()
+        )
+
+        for r in results:
+            assert r.properties.name.startswith("John")
+
+    def test_complex_patterns(self, text_search_store):
+        """Should match complex patterns."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .wildcard_search("*@*.com", "email")
+            .r()
+        )
+
+        assert len(results) > 0
+
+    def test_no_matches(self, text_search_store):
+        """Should return empty when pattern doesn't match."""
+        results = (
+            GraphQuery(text_search_store).classId("Person").wildcard_search("XYZ*").r()
+        )
+
+        assert results == []
+
+    def test_empty_pattern(self, text_search_store):
+        """Should handle empty pattern."""
+        all_persons = GraphQuery(text_search_store).classId("Person").r()
+        filtered = (
+            GraphQuery(text_search_store).classId("Person").wildcard_search("").r()
+        )
+
+        assert len(filtered) == len(all_persons)
+
+    def test_chaining(self, text_search_store):
+        """Should chain with other methods."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .wildcard_search("J*")
+            .where("status", FilterOperator.EQ, "active")
+            .r()
+        )
+
+        assert isinstance(results, list)
+
+
+class TestPrefixSearch:
+    """Test prefixSearch method."""
+
+    def test_prefix_on_name(self, text_search_store):
+        """Should match by prefix on name property."""
+        results = (
+            GraphQuery(text_search_store).classId("Person").prefix_search("joh").r()
+        )
+
+        assert len(results) > 0
+        for r in results:
+            assert r.properties.name.lower().startswith("joh")
+
+    def test_specific_property(self, text_search_store):
+        """Should search on specific property."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .prefix_search("john@", "email")
+            .r()
+        )
+
+        assert len(results) > 0
+        for r in results:
+            assert r.properties.email.lower().startswith("john@")
+
+    def test_case_sensitive(self, text_search_store):
+        """Should support case sensitive search."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .prefix_search("John", "name", {"case_sensitive": True})
+            .r()
+        )
+
+        for r in results:
+            assert r.properties.name.startswith("John")
+
+    def test_minimum_length(self, text_search_store):
+        """Should enforce minimum length."""
+        all_persons = GraphQuery(text_search_store).classId("Person").r()
+        filtered = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .prefix_search("j", "name", {"min_length": 3})
+            .r()
+        )
+
+        # Should return all (prefix too short)
+        assert len(filtered) == len(all_persons)
+
+    def test_no_matches(self, text_search_store):
+        """Should return empty when no prefix matches."""
+        results = (
+            GraphQuery(text_search_store).classId("Person").prefix_search("xyz").r()
+        )
+
+        assert results == []
+
+    def test_empty_prefix(self, text_search_store):
+        """Should handle empty prefix."""
+        all_persons = GraphQuery(text_search_store).classId("Person").r()
+        filtered = GraphQuery(text_search_store).classId("Person").prefix_search("").r()
+
+        assert len(filtered) == len(all_persons)
+
+    def test_autocomplete_use_case(self, text_search_store):
+        """Should work for autocomplete use case."""
+        results = (
+            GraphQuery(text_search_store).classId("Person").prefix_search("ja").r()
+        )
+
+        assert isinstance(results, list)
+
+    def test_chaining(self, text_search_store):
+        """Should chain with other filters."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .prefix_search("j")
+            .where("age", FilterOperator.GTE, 25)
+            .r()
+        )
+
+        assert isinstance(results, list)
+        for r in results:
+            assert r.properties.age >= 25
+
+
+class TestSearchInProperties:
+    """Test searchInProperties method."""
+
+    def test_search_in_specified_properties(self, text_search_store):
+        """Should search in specified properties."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .search_in_properties("developer", ["bio", "name"])
+            .r()
+        )
+
+        assert len(results) > 0
+        for r in results:
+            bio_match = (
+                "developer" in r.properties.bio.lower()
+                if hasattr(r.properties, "bio") and r.properties.bio
+                else False
+            )
+            name_match = (
+                "developer" in r.properties.name.lower()
+                if hasattr(r.properties, "name") and r.properties.name
+                else False
+            )
+            assert bio_match or name_match
+
+    def test_highlight_matches(self, text_search_store):
+        """Should support highlight matches option."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .search_in_properties(
+                "john", ["name", "email"], {"highlight_matches": True}
+            )
+            .r()
+        )
+
+        assert len(results) > 0
+        # Check that _matched_fields is stored in properties.extra_properties
+        for r in results:
+            assert "_matched_fields" in r.properties.extra_properties
+            assert isinstance(r.properties.extra_properties["_matched_fields"], list)
+
+    def test_case_sensitive(self, text_search_store):
+        """Should support case sensitive search."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .search_in_properties("John", ["name"], {"case_sensitive": True})
+            .r()
+        )
+
+        for r in results:
+            assert "John" in r.properties.name
+
+    def test_minimum_match_length(self, text_search_store):
+        """Should enforce minimum match length."""
+        all_persons = GraphQuery(text_search_store).classId("Person").r()
+        filtered = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .search_in_properties("j", ["name"], {"min_match_length": 3})
+            .r()
+        )
+
+        # Query too short, should return all
+        assert len(filtered) == len(all_persons)
+
+    def test_no_matches(self, text_search_store):
+        """Should return empty when no matches in properties."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .search_in_properties("xyz123", ["name", "email"])
+            .r()
+        )
+
+        assert results == []
+
+    def test_empty_property_list(self, text_search_store):
+        """Should handle empty property list."""
+        all_persons = GraphQuery(text_search_store).classId("Person").r()
+        filtered = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .search_in_properties("john", [])
+            .r()
+        )
+
+        assert len(filtered) == len(all_persons)
+
+    def test_empty_query(self, text_search_store):
+        """Should handle empty query."""
+        all_persons = GraphQuery(text_search_store).classId("Person").r()
+        filtered = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .search_in_properties("", ["name"])
+            .r()
+        )
+
+        assert len(filtered) == len(all_persons)
+
+    def test_multiple_properties(self, text_search_store):
+        """Should match across multiple properties."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .search_in_properties("example", ["email", "name"])
+            .r()
+        )
+
+        assert len(results) > 0
+
+    def test_chaining(self, text_search_store):
+        """Should chain with other filters."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .search_in_properties("john", ["name"])
+            .where("status", FilterOperator.EQ, "active")
+            .r()
+        )
+
+        assert isinstance(results, list)
+
+    def test_non_string_properties(self, text_search_store):
+        """Should handle non-string properties gracefully."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .search_in_properties("25", ["age", "name"])
+            .r()
+        )
+
+        # Should only search string properties, ignore 'age' (number)
+        assert isinstance(results, list)
+
+
+class TestPhase1Integration:
+    """Integration tests for Phase 1 methods."""
+
+    def test_chain_full_text_with_wildcard(self, text_search_store):
+        """Should chain fullTextSearch with wildcardSearch."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .full_text_search("john", {"properties": ["name"]})
+            .wildcard_search("*@example.com", "email")
+            .r()
+        )
+
+        assert isinstance(results, list)
+
+    def test_chain_prefix_with_search_in_properties(self, text_search_store):
+        """Should chain prefixSearch with searchInProperties."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .prefix_search("j")
+            .search_in_properties("developer", ["bio"])
+            .r()
+        )
+
+        assert isinstance(results, list)
+
+    def test_combine_all_phase1_methods(self, text_search_store):
+        """Should combine all Phase 1 methods in a single query."""
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .full_text_search("john jane", {"operator": "OR"})
+            .prefix_search("j")
+            .wildcard_search("*@*.com", "email")
+            .r()
+        )
+
+        assert isinstance(results, list)
+
+    def test_serialization_deserialization(self, text_search_store):
+        """Should serialize and deserialize Phase 1 operations."""
+        query1 = (
+            GraphQuery(text_search_store)
+            .classId("Person")
+            .full_text_search("john")
+            .wildcard_search("J*")
+        )
+
+        operations = query1.query_operations
+        assert any(op.method == QueryOperations.FULL_TEXT_SEARCH for op in operations)
+        assert any(op.method == QueryOperations.WILDCARD_SEARCH for op in operations)
+
+        # Deserialize and execute
+        query2 = GraphQuery(text_search_store)
+        query2.construct_query(operations)
+        results = query2.r()
+
+        assert isinstance(results, list)
+
+    def test_complex_search_scenario(self, text_search_store):
+        """Should handle complex search scenarios."""
+        # Simulate autocomplete with highlighting
+        results = (
+            GraphQuery(text_search_store)
+            .classId("Article")
+            .prefix_search("int", "title")
+            .search_in_properties(
+                "python", ["title", "content"], {"highlight_matches": True}
+            )
+            .r()
+        )
+
+        assert isinstance(results, list)
+        if results:
+            for r in results:
+                if "_matched_fields" in r.properties.extra_properties:
+                    assert isinstance(
+                        r.properties.extra_properties["_matched_fields"], list
+                    )
+
+
+# ===== PHASE 2: ADVANCED TEXT SEARCH METHODS =====
+
+
+@pytest.fixture
+def phrase_search_store():
+    """Create a store with phrase-rich data for phrase search testing."""
+    store = ElementStore()
+
+    elements_data = [
+        {
+            "id": "job-1",
+            "class_id": "Job",
+            "title": "Senior Software Engineer",
+            "description": "We are looking for a software engineer with senior experience",
+            "company": "TechCorp",
+            "location": "San Francisco",
+        },
+        {
+            "id": "job-2",
+            "class_id": "Job",
+            "title": "Software Engineer Senior",
+            "description": "Join our team as a senior-level engineer",
+            "company": "StartupXYZ",
+            "location": "Austin",
+        },
+        {
+            "id": "job-3",
+            "class_id": "Job",
+            "title": "Junior Developer",
+            "description": "Entry level position for new graduates",
+            "company": "DevShop",
+            "location": "Remote",
+        },
+        {
+            "id": "article-1",
+            "class_id": "Article",
+            "title": "Understanding Machine Learning",
+            "abstract": "This paper explores machine learning algorithms and their applications",
+            "content": "Machine learning is transforming how we analyze data. Deep machine learning models...",
+            "author": "Dr. Smith",
+        },
+        {
+            "id": "article-2",
+            "class_id": "Article",
+            "title": "Climate Change Impact",
+            "abstract": "Climate change is affecting ecosystems worldwide",
+            "content": "The effects of climate change are visible in rising temperatures...",
+            "author": "Dr. Johnson",
+        },
+        {
+            "id": "article-3",
+            "class_id": "Article",
+            "title": "Legal Contracts",
+            "abstract": "Understanding force majeure clauses",
+            "content": "Force Majeure clauses protect parties from unforeseen circumstances. A force majeure event...",
+            "author": "Attorney Brown",
+        },
+    ]
+
+    for elem_data in elements_data:
+        element_id = elem_data.pop("id")
+        class_id = elem_data.pop("class_id")
+        properties = ElementProperties(**elem_data)
+        details = ElementDetails(
+            id=element_id, class_id=class_id, type=NodeTypes.NODE, properties=properties
+        )
+        element = BaseElement(details, store)
+        store.elements[element_id] = element
+
+    return store
+
+
+class TestPhraseSearch:
+    """Test phrase_search method."""
+
+    def test_exact_phrase_matches(self, phrase_search_store):
+        """Should find exact phrase matches in correct order."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("software engineer")
+            .r()
+        )
+
+        # Should match "Senior Software Engineer" and description text
+        assert len(results) > 0
+        assert any("software engineer" in r.properties.title.lower() for r in results)
+
+    def test_not_match_reversed_order(self, phrase_search_store):
+        """Should NOT match when words are in different order."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("engineer software")
+            .r()
+        )
+
+        # Should not match "Software Engineer" (wrong order)
+        # But might match "engineer with senior" in description if slop allows
+        # With slop=0 (default), should only match exact order
+        title_matches = [r for r in results if "title" in dir(r.properties)]
+        for r in title_matches:
+            if hasattr(r.properties, "title"):
+                # Reversed phrase should not appear in exact form
+                assert "engineer software" not in r.properties.title.lower()
+
+    def test_slop_parameter_proximity(self, phrase_search_store):
+        """Should match with slop parameter allowing words in between."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Article")
+            .phrase_search("machine learning", {"slop": 1})
+            .r()
+        )
+
+        # Should match "machine learning" and "Deep machine learning"
+        assert len(results) > 0
+
+    def test_higher_slop_values(self, phrase_search_store):
+        """Should allow more words between phrase words with higher slop."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("software engineer", {"slop": 2})
+            .r()
+        )
+
+        # With slop=2, can match "software [word] [word] engineer"
+        assert len(results) > 0
+
+    def test_specific_properties(self, phrase_search_store):
+        """Should search only in specified properties."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("software engineer", {"properties": ["title"]})
+            .r()
+        )
+
+        # Should only search titles
+        assert len(results) > 0
+        for r in results:
+            # Verify match is in title
+            if hasattr(r.properties, "title"):
+                assert (
+                    "software" in r.properties.title.lower()
+                    or "engineer" in r.properties.title.lower()
+                )
+
+    def test_case_sensitive(self, phrase_search_store):
+        """Should respect case sensitivity option."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Article")
+            .phrase_search("Force Majeure", {"case_sensitive": True})
+            .r()
+        )
+
+        # Should match exact case "Force Majeure"
+        assert len(results) > 0
+
+    def test_case_insensitive_default(self, phrase_search_store):
+        """Should be case insensitive by default."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Article")
+            .phrase_search("force majeure")
+            .r()
+        )
+
+        # Should match "Force Majeure" (case insensitive)
+        assert len(results) > 0
+
+    def test_highlight_matches(self, phrase_search_store):
+        """Should add matched fields when highlightMatches is true."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Article")
+            .phrase_search("climate change", {"highlight_matches": True})
+            .r()
+        )
+
+        assert len(results) > 0
+        # Check for _matched_fields
+        for r in results:
+            assert "_matched_fields" in r.properties.extra_properties
+            assert isinstance(r.properties.extra_properties["_matched_fields"], list)
+            assert len(r.properties.extra_properties["_matched_fields"]) > 0
+
+    def test_no_matches(self, phrase_search_store):
+        """Should return empty array when no matches found."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("quantum computing")
+            .r()
+        )
+
+        assert len(results) == 0
+
+    def test_empty_phrase(self, phrase_search_store):
+        """Should handle empty phrase gracefully."""
+        results = GraphQuery(phrase_search_store).classId("Job").phrase_search("").r()
+
+        # Should return all jobs (no filtering)
+        assert len(results) == 3
+
+    def test_single_word(self, phrase_search_store):
+        """Should work with single word phrases."""
+        results = (
+            GraphQuery(phrase_search_store).classId("Job").phrase_search("software").r()
+        )
+
+        assert len(results) > 0
+
+    def test_multiple_spaces(self, phrase_search_store):
+        """Should handle multiple spaces in phrase."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("software    engineer")
+            .r()
+        )
+
+        # Should normalize spaces and match
+        assert len(results) > 0
+
+    def test_chain_methods(self, phrase_search_store):
+        """Should chain with other query methods."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("software engineer")
+            .r()
+        )
+
+        assert isinstance(results, list)
+
+    def test_with_full_text_search(self, phrase_search_store):
+        """Should work with fullTextSearch for combined queries."""
+        # First add text_search capability to store
+        # This tests that phrase_search can be chained
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Article")
+            .phrase_search("machine learning")
+            .r()
+        )
+
+        assert isinstance(results, list)
+
+    def test_serialization(self, phrase_search_store):
+        """Should serialize phrase_search operations."""
+        query = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("software engineer", {"slop": 1, "highlight_matches": True})
+        )
+
+        operations = query.query_operations
+        phrase_ops = [
+            op for op in operations if op.method == QueryOperations.PHRASE_SEARCH
+        ]
+
+        assert len(phrase_ops) == 1
+        assert phrase_ops[0].params["phrase"] == "software engineer"
+        assert phrase_ops[0].params["options"]["slop"] == 1
+        assert phrase_ops[0].params["options"]["highlight_matches"]
+
+    def test_deserialization(self, phrase_search_store):
+        """Should deserialize and reconstruct phrase_search operations."""
+        query1 = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("software engineer")
+        )
+
+        operations = query1.query_operations
+
+        # Deserialize
+        query2 = GraphQuery(phrase_search_store)
+        query2.construct_query(operations)
+        results = query2.r()
+
+        assert isinstance(results, list)
+        assert len(results) > 0
+
+    def test_exact_with_slop_0(self, phrase_search_store):
+        """Should require exact match with slop=0."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Article")
+            .phrase_search("machine learning", {"slop": 0})
+            .r()
+        )
+
+        # Should only match exact "machine learning" without words in between
+        # Article-1 has "machine learning" in title and content
+        assert len(results) > 0
+
+    def test_insufficient_slop(self, phrase_search_store):
+        """Should not match when slop is insufficient."""
+        # "Deep machine learning" has 1 word between "machine" and "learning"
+        # With slop=0, should not match
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Article")
+            .phrase_search("deep learning", {"slop": 0})
+            .r()
+        )
+
+        # "deep learning" doesn't appear consecutively
+        # Should only match if exact phrase exists
+        for r in results:
+            if hasattr(r.properties, "content"):
+                # Check if "deep learning" appears exactly
+                assert "deep learning" in r.properties.content.lower()
+
+    def test_all_text_properties(self, phrase_search_store):
+        """Should search all text properties by default."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Article")
+            .phrase_search("force majeure")
+            .r()
+        )
+
+        # Should find in abstract OR content
+        assert len(results) > 0
+
+    def test_nonexistent_properties(self, phrase_search_store):
+        """Should handle nonexistent properties gracefully."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("software engineer", {"properties": ["nonexistent"]})
+            .r()
+        )
+
+        # Should return no results (property doesn't exist)
+        assert len(results) == 0
+
+    def test_with_where_filter(self, phrase_search_store):
+        """Should combine with where filters."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("software engineer")
+            .where("location", FilterOperator.EQ, "San Francisco")
+            .r()
+        )
+
+        assert isinstance(results, list)
+        # If any results, should be in San Francisco
+        for r in results:
+            if hasattr(r.properties, "location"):
+                assert r.properties.location == "San Francisco"
+
+
+class TestPhase2Integration:
+    """Integration tests for Phase 2 methods."""
+
+    def test_chain_phrase_with_full_text(self, phrase_search_store):
+        """Should chain phraseSearch with fullTextSearch."""
+        # Phrase search then full text search
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Article")
+            .phrase_search("machine learning")
+            # Note: full_text_search would filter from phrase results
+            .r()
+        )
+
+        assert isinstance(results, list)
+
+    def test_phrase_with_prefix(self, phrase_search_store):
+        """Should chain phraseSearch with prefixSearch."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Job")
+            .phrase_search("software engineer")
+            .r()
+        )
+
+        assert isinstance(results, list)
+
+    def test_complex_search_combination(self, phrase_search_store):
+        """Should handle complex combinations of search methods."""
+        results = (
+            GraphQuery(phrase_search_store)
+            .classId("Article")
+            .phrase_search("machine learning", {"highlight_matches": True})
+            .r()
+        )
+
+        assert isinstance(results, list)
+        if results:
+            for r in results:
+                if "_matched_fields" in r.properties.extra_properties:
+                    assert isinstance(
+                        r.properties.extra_properties["_matched_fields"], list
+                    )
+
+
 if __name__ == "__main__":
     pytest.main([__file__, "-v"])
